@@ -29,7 +29,7 @@ describe('Ultron', function () {
 
   it('assigns a unique id to every instance', function () {
     for (var i = 0; i < 100; i++) {
-	assert.notEqual(ultron.id, ((new Ultron()).id));
+      assert.notEqual(ultron.id, ((new Ultron()).id));
     }
   });
 
@@ -108,14 +108,14 @@ describe('Ultron', function () {
       function foo() {}
       ultron.once('foo', foo);
       assert.equal(ee.listeners('foo').length, 1);
-      console.log("FIXME: ", ee.listeners('foo')[0], foo);
+      assert.equal(ee.listeners('foo')[0], foo);
     });
 
     it('tags the assigned function', function () {
       assert.equal(ee.listeners('foo').length, 0);
 
       ultron.once('foo', function () {});
-      console.log("FIXME: ", ee.listeners('foo')[0].__ultron, ultron.id);
+      assert.equal(ee.listeners('foo')[0].__ultron, ultron.id);
     });
 
     it('also passes in the context', function (next) {
@@ -176,7 +176,7 @@ describe('Ultron', function () {
 
       ultron.remove('foo');
       assert.equal(ee.listeners('foo').length, 1);
-      console.log("FIXME: ", ee.listeners('foo')[0], foo);
+      assert.equal(ee.listeners('foo')[0], foo);
 
       ee.removeAllListeners();
       ultron.destroy();
@@ -195,7 +195,7 @@ describe('Ultron', function () {
       // In Node.js 8+ `EventEmitter#listeners()` returns the original listener
       // also for once listeners.
       //
-      assert.equal(ee.listeners('foo')[0].listener, foo);
+      assert.equal(actual.listener || actual, foo);
     });
 
     it('removes all assigned events if called without args', function () {
